@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.17';
+$VERSION = '5.18';
 
 =head1 NAME
 
@@ -40,7 +40,7 @@ require Exporter;
                     GetImage SaveImageFile MirrorImageFile
                     CopyPhotoFile SavePhotoFile
                     GetMedia SaveMedia SaveFile DeleteFile UnZipFile
-                    GetImageSize GetGravatar
+                    GetImageSize ResizeDimensions GetGravatar
                 ) ]
 );
 
@@ -261,15 +261,22 @@ the following:
   imageid   - if overwriting already existing file
   stock     - file category (used to define the save directory)
 
-=item MirrorImageFile
+=item MirrorImageFile($source,$stock [,$xmax,$ymax] )
 
-Mirrors a file from a URL to the local file system.
+Mirrors a file from a URL to the local file system. If a max width and height
+are given, will resize the image.
 
-=item GetImageSize
+=item GetImageSize($link,$size,$width,$height,$maxwidth,$maxheight)
 
 For a given file, returns the true width and height that will be rendered
 within the browser, given the current and default settings.
 
+=item ResizeDimensions($dimensions,$file,$maxwidth,$maxheight)
+
+Given the current dimensions, file and intended max height and width, will 
+return the width and height values to use in a image tag to scale the 
+dimensions to the require box size.
+
 =item GetGravatar
 
 Returns a Gravatar link.
@@ -307,8 +314,10 @@ sub MirrorImageFile {
     my $mechanize = WWW::Mechanize->new();
     $mechanize->mirror( $source, $target );
 
-    my $i = Labyrinth::DIUtils->new($target);
-    $i->reduce($xmax,$ymax);
+    if($xmax && $ymax) {
+        my $i = Labyrinth::DIUtils->new($target);
+        $i->reduce($xmax,$ymax);
+    }
 
     my ($size_x,$size_y) = imgsize($target);
 
@@ -390,6 +399,36 @@ sub GetImageSize {
     return ($width,$height);
 }
 
+sub ResizeDimensions {
+    my ($dimensions,$file,$maxwidth,$maxheight) = @_;
+    my $toobig = 0;
+    my ($x,$y);
+
+    if($tvars{data}->{dimensions}) {
+        ($x,$y) = split("x",$tvars{data}->{dimensions});
+    } else {
+        ($x,$y) = imgsize($file)  if(-f $file);
+    }
+
+    return                  unless($x && $y);
+    return ($x,$y,$toobig)  unless($maxwidth && $maxheight);
+    return ($x,$y,$toobig)  if($x <= $maxwidth && $y <= $maxheight);
+
+    $toobig = 1;
+    my $xr = $maxwidth  ? $maxwidth  / $x : 0;
+    my $yr = $maxheight ? $maxheight / $y : 0;
+
+    if($xr <= $yr) {
+        $x *= $xr;
+        $y *= $xr;
+    } else {
+        $x *= $yr;
+        $y *= $yr;
+    }
+
+    return (int($x),int($y),$toobig);
+}
+
 sub GetGravatar {
     my ($id,$email) = @_;
     my $nophoto = uri_escape($settings{nophoto});
